pub(crate) struct AbstractGregorian<Y: GregorianYears>(pub Y);Tuple Fields
0: YTrait Implementations
Sourceimpl<Y: GregorianYears> Calendar for AbstractGregorian<Y>
impl<Y: GregorianYears> Calendar for AbstractGregorian<Y>
Sourcetype DateInner = ArithmeticDate<AbstractGregorian<IsoEra>>
type DateInner = ArithmeticDate<AbstractGregorian<IsoEra>>
The internal type used to represent dates Read more
Sourcetype DifferenceError = Infallible
type DifferenceError = Infallible
The type of error returned by
untilSourcefn from_codes(
&self,
era: Option<&str>,
year: i32,
month_code: MonthCode,
day: u8,
) -> Result<Self::DateInner, DateError>
fn from_codes( &self, era: Option<&str>, year: i32, month_code: MonthCode, day: u8, ) -> Result<Self::DateInner, DateError>
Construct a date from era/month codes and fields Read more
Sourcefn has_cheap_iso_conversion(&self) -> bool
fn has_cheap_iso_conversion(&self) -> bool
Whether
from_iso/to_iso is more efficient
than from_rata_die/to_rata_die.Sourcefn from_iso(&self, iso: IsoDateInner) -> Self::DateInner
fn from_iso(&self, iso: IsoDateInner) -> Self::DateInner
Construct the date from an ISO date. Read more
Sourcefn to_iso(&self, date: &Self::DateInner) -> IsoDateInner
fn to_iso(&self, date: &Self::DateInner) -> IsoDateInner
Obtain an ISO date from this date. Read more
Sourcefn months_in_year(&self, date: &Self::DateInner) -> u8
fn months_in_year(&self, date: &Self::DateInner) -> u8
Count the number of months in a given year, specified by providing a date
from that year
Sourcefn days_in_year(&self, date: &Self::DateInner) -> u16
fn days_in_year(&self, date: &Self::DateInner) -> u16
Count the number of days in a given year, specified by providing a date
from that year
Sourcefn days_in_month(&self, date: &Self::DateInner) -> u8
fn days_in_month(&self, date: &Self::DateInner) -> u8
Count the number of days in a given month, specified by providing a date
from that year/month
Sourcefn is_in_leap_year(&self, date: &Self::DateInner) -> bool
fn is_in_leap_year(&self, date: &Self::DateInner) -> bool
Calculate if a date is in a leap year
Sourcefn month(&self, date: &Self::DateInner) -> MonthInfo
fn month(&self, date: &Self::DateInner) -> MonthInfo
The calendar-specific month represented by
dateSourcefn day_of_month(&self, date: &Self::DateInner) -> DayOfMonth
fn day_of_month(&self, date: &Self::DateInner) -> DayOfMonth
The calendar-specific day-of-month represented by
dateSourcefn day_of_year(&self, date: &Self::DateInner) -> DayOfYear
fn day_of_year(&self, date: &Self::DateInner) -> DayOfYear
Information of the day of the year
Sourcefn debug_name(&self) -> &'static str
fn debug_name(&self) -> &'static str
Obtain a name for the calendar for debug printing
Sourcefn calendar_algorithm(&self) -> Option<CalendarAlgorithm>
fn calendar_algorithm(&self) -> Option<CalendarAlgorithm>
Returns the
CalendarAlgorithm that is required to match
when parsing into this calendar. Read moreSourcefn extended_year(&self, date: &Self::DateInner) -> i32
fn extended_year(&self, date: &Self::DateInner) -> i32
The extended year.
Sourceimpl<Y: Clone + GregorianYears> Clone for AbstractGregorian<Y>
impl<Y: Clone + GregorianYears> Clone for AbstractGregorian<Y>
Sourcefn clone(&self) -> AbstractGregorian<Y>
fn clone(&self) -> AbstractGregorian<Y>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<Y: GregorianYears> DateFieldsResolver for AbstractGregorian<Y>
impl<Y: GregorianYears> DateFieldsResolver for AbstractGregorian<Y>
Sourcetype YearInfo = i32
type YearInfo = i32
This stores the year as either an i32, or a type containing more
useful computational information.
fn days_in_provided_month(year: i32, month: u8) -> u8
fn months_in_provided_year(_: i32) -> u8
Sourcefn year_info_from_era(
&self,
era: &[u8],
era_year: i32,
) -> Result<Self::YearInfo, UnknownEraError>
fn year_info_from_era( &self, era: &[u8], era_year: i32, ) -> Result<Self::YearInfo, UnknownEraError>
Converts the era and era year to a YearInfo. If the calendar does not have eras,
this should always return an Err result.
Sourcefn year_info_from_extended(&self, extended_year: i32) -> Self::YearInfo
fn year_info_from_extended(&self, extended_year: i32) -> Self::YearInfo
Converts an extended year to a YearInfo.
Sourcefn reference_year_from_month_day(
&self,
_month_code: ValidMonthCode,
_day: u8,
) -> Result<Self::YearInfo, EcmaReferenceYearError>
fn reference_year_from_month_day( &self, _month_code: ValidMonthCode, _day: u8, ) -> Result<Self::YearInfo, EcmaReferenceYearError>
Calculates the ECMA reference year for the month code and day, or an error
if the month code and day are invalid. Read more
Sourcefn ordinal_month_from_code(
&self,
_year: &Self::YearInfo,
month_code: ValidMonthCode,
_options: DateFromFieldsOptions,
) -> Result<u8, MonthCodeError>
fn ordinal_month_from_code( &self, _year: &Self::YearInfo, month_code: ValidMonthCode, _options: DateFromFieldsOptions, ) -> Result<u8, MonthCodeError>
Calculates the ordinal month for the given year and month code. Read more
Sourcefn month_code_from_ordinal(
&self,
_year: &Self::YearInfo,
ordinal_month: u8,
) -> ValidMonthCode
fn month_code_from_ordinal( &self, _year: &Self::YearInfo, ordinal_month: u8, ) -> ValidMonthCode
Calculates the month code from the given ordinal month and year. Read more
Sourceimpl<Y: Debug + GregorianYears> Debug for AbstractGregorian<Y>
impl<Y: Debug + GregorianYears> Debug for AbstractGregorian<Y>
Sourceimpl<Y: Default + GregorianYears> Default for AbstractGregorian<Y>
impl<Y: Default + GregorianYears> Default for AbstractGregorian<Y>
Sourcefn default() -> AbstractGregorian<Y>
fn default() -> AbstractGregorian<Y>
Returns the “default value” for a type. Read more
Sourceimpl<Y: Hash + GregorianYears> Hash for AbstractGregorian<Y>
impl<Y: Hash + GregorianYears> Hash for AbstractGregorian<Y>
Sourceimpl<Y: Ord + GregorianYears> Ord for AbstractGregorian<Y>
impl<Y: Ord + GregorianYears> Ord for AbstractGregorian<Y>
Sourcefn cmp(&self, other: &AbstractGregorian<Y>) -> Ordering
fn cmp(&self, other: &AbstractGregorian<Y>) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<Y: PartialEq + GregorianYears> PartialEq for AbstractGregorian<Y>
impl<Y: PartialEq + GregorianYears> PartialEq for AbstractGregorian<Y>
Sourcefn eq(&self, other: &AbstractGregorian<Y>) -> bool
fn eq(&self, other: &AbstractGregorian<Y>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<Y: PartialOrd + GregorianYears> PartialOrd for AbstractGregorian<Y>
impl<Y: PartialOrd + GregorianYears> PartialOrd for AbstractGregorian<Y>
impl<Y: Copy + GregorianYears> Copy for AbstractGregorian<Y>
impl<Y: Eq + GregorianYears> Eq for AbstractGregorian<Y>
impl<Y: GregorianYears> StructuralPartialEq for AbstractGregorian<Y>